@@ -50,6 +50,7 @@ func getInstanceConfigInterfacesCreateOptionsList(
 	for index, configInterface := range interfaces {
 		interfaceOptsList[index] = configInterface.GetCreateOptions()
 	}
+
 	return interfaceOptsList
 }
 
@@ -108,12 +109,7 @@ func (c *Client) AppendInstanceConfigInterface(
 	opts InstanceConfigInterfaceCreateOptions,
 ) (*InstanceConfigInterface, error) {
 	e := formatAPIPath("/linode/instances/%d/configs/%d/interfaces", linodeID, configID)
-	response, err := doPOSTRequest[InstanceConfigInterface](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPOSTRequest[InstanceConfigInterface](ctx, c, e, opts)
 }
 
 func (c *Client) GetInstanceConfigInterface(
@@ -128,12 +124,8 @@ func (c *Client) GetInstanceConfigInterface(
 		configID,
 		interfaceID,
 	)
-	response, err := doGETRequest[InstanceConfigInterface](ctx, c, e)
-	if err != nil {
-		return nil, err
-	}
 
-	return response, nil
+	return doGETRequest[InstanceConfigInterface](ctx, c, e)
 }
 
 func (c *Client) ListInstanceConfigInterfaces(
@@ -146,6 +138,7 @@ func (c *Client) ListInstanceConfigInterfaces(
 		linodeID,
 		configID,
 	)
+
 	response, err := doGETRequest[[]InstanceConfigInterface](ctx, c, e)
 	if err != nil {
 		return nil, err
@@ -167,12 +160,8 @@ func (c *Client) UpdateInstanceConfigInterface(
 		configID,
 		interfaceID,
 	)
-	response, err := doPUTRequest[InstanceConfigInterface](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
 
-	return response, nil
+	return doPUTRequest[InstanceConfigInterface](ctx, c, e, opts)
 }
 
 func (c *Client) DeleteInstanceConfigInterface(
@@ -187,8 +176,8 @@ func (c *Client) DeleteInstanceConfigInterface(
 		configID,
 		interfaceID,
 	)
-	err := doDELETERequest(ctx, c, e)
-	return err
+
+	return doDELETERequest(ctx, c, e)
 }
 
 func (c *Client) ReorderInstanceConfigInterfaces(
@@ -202,7 +191,6 @@ func (c *Client) ReorderInstanceConfigInterfaces(
 		linodeID,
 		configID,
 	)
-	_, err := doPOSTRequest[OAuthClient](ctx, c, e, opts)
 
-	return err
+	return doPOSTRequestNoResponseBody(ctx, c, e, opts)
 }
