@@ -9,6 +9,13 @@ import (
 	"github.com/linode/linodego/internal/parseabletime"
 )
 
+type InterfaceGeneration string
+
+const (
+	GenerationLegacyConfig InterfaceGeneration = "legacy_config"
+	GenerationLinode       InterfaceGeneration = "linode"
+)
+
 /*
  * https://techdocs.akamai.com/linode-api/reference/post-linode-instance
  */
@@ -41,33 +48,38 @@ const (
 
 // Instance represents a linode object
 type Instance struct {
-	ID              int             `json:"id"`
-	Created         *time.Time      `json:"-"`
-	Updated         *time.Time      `json:"-"`
-	Region          string          `json:"region"`
-	Alerts          *InstanceAlert  `json:"alerts"`
-	Backups         *InstanceBackup `json:"backups"`
-	Image           string          `json:"image"`
-	Group           string          `json:"group"`
-	IPv4            []*net.IP       `json:"ipv4"`
-	IPv6            string          `json:"ipv6"`
-	Label           string          `json:"label"`
-	Type            string          `json:"type"`
-	Status          InstanceStatus  `json:"status"`
-	HasUserData     bool            `json:"has_user_data"`
-	Hypervisor      string          `json:"hypervisor"`
-	HostUUID        string          `json:"host_uuid"`
-	Specs           *InstanceSpec   `json:"specs"`
-	WatchdogEnabled bool            `json:"watchdog_enabled"`
-	Tags            []string        `json:"tags"`
-
-	PlacementGroup *InstancePlacementGroup `json:"placement_group"`
+	ID              int                     `json:"id"`
+	Created         *time.Time              `json:"-"`
+	Updated         *time.Time              `json:"-"`
+	Region          string                  `json:"region"`
+	Alerts          *InstanceAlert          `json:"alerts"`
+	Backups         *InstanceBackup         `json:"backups"`
+	Image           string                  `json:"image"`
+	Group           string                  `json:"group"`
+	IPv4            []*net.IP               `json:"ipv4"`
+	IPv6            string                  `json:"ipv6"`
+	Label           string                  `json:"label"`
+	Type            string                  `json:"type"`
+	Status          InstanceStatus          `json:"status"`
+	HasUserData     bool                    `json:"has_user_data"`
+	Hypervisor      string                  `json:"hypervisor"`
+	HostUUID        string                  `json:"host_uuid"`
+	Specs           *InstanceSpec           `json:"specs"`
+	WatchdogEnabled bool                    `json:"watchdog_enabled"`
+	Tags            []string                `json:"tags"`
+	PlacementGroup  *InstancePlacementGroup `json:"placement_group"`
 
 	// NOTE: Disk encryption may not currently be available to all users.
 	DiskEncryption InstanceDiskEncryption `json:"disk_encryption"`
 
 	LKEClusterID int      `json:"lke_cluster_id"`
 	Capabilities []string `json:"capabilities"`
+
+	// Note: Linode interfaces may not currently be available to all users.
+	InterfaceGeneration InterfaceGeneration `json:"interface_generation"`
+
+	// NOTE: MaintenancePolicy can only be used with v4beta.
+	MaintenancePolicy string `json:"maintenance_policy"`
 }
 
 // InstanceSpec represents a linode spec
@@ -120,6 +132,7 @@ type InstanceTransfer struct {
 }
 
 // MonthlyInstanceTransferStats pool stats for a Linode Instance network transfer statistics for a specific month
+// Deprecated: use MonthlyInstanceTransferStatsV2 for new implementations
 type MonthlyInstanceTransferStats struct {
 	// The amount of inbound public network traffic received by this Linode, in bytes, for a specific year/month.
 	BytesIn int `json:"bytes_in"`
@@ -131,6 +144,18 @@ type MonthlyInstanceTransferStats struct {
 	BytesTotal int `json:"bytes_total"`
 }
 
+// MonthlyInstanceTransferStatsV2 pool stats for a Linode Instance network transfer statistics for a specific month
+type MonthlyInstanceTransferStatsV2 struct {
+	// The amount of inbound public network traffic received by this Linode, in bytes, for a specific year/month.
+	BytesIn uint64 `json:"bytes_in"`
+
+	// The amount of outbound public network traffic sent by this Linode, in bytes, for a specific year/month.
+	BytesOut uint64 `json:"bytes_out"`
+
+	// The total amount of public network traffic sent and received by this Linode, in bytes, for a specific year/month.
+	BytesTotal uint64 `json:"bytes_total"`
+}
+
 // InstancePlacementGroup represents information about the placement group
 // this Linode is a part of.
 type InstancePlacementGroup struct {
@@ -138,7 +163,7 @@ type InstancePlacementGroup struct {
 	Label                string               `json:"label"`
 	PlacementGroupType   PlacementGroupType   `json:"placement_group_type"`
 	PlacementGroupPolicy PlacementGroupPolicy `json:"placement_group_policy"`
-	MigratingTo          string               `json:"migrating_to"` // read-only
+	MigratingTo          *int                 `json:"migrating_to"` // read-only
 }
 
 // InstanceMetadataOptions specifies various Instance creation fields
@@ -155,22 +180,23 @@ type InstancePasswordResetOptions struct {
 
 // InstanceCreateOptions require only Region and Type
 type InstanceCreateOptions struct {
-	Region          string                                 `json:"region"`
-	Type            string                                 `json:"type"`
-	Label           string                                 `json:"label,omitempty"`
-	RootPass        string                                 `json:"root_pass,omitempty"`
-	AuthorizedKeys  []string                               `json:"authorized_keys,omitempty"`
-	AuthorizedUsers []string                               `json:"authorized_users,omitempty"`
-	StackScriptID   int                                    `json:"stackscript_id,omitempty"`
-	StackScriptData map[string]string                      `json:"stackscript_data,omitempty"`
-	BackupID        int                                    `json:"backup_id,omitempty"`
-	Image           string                                 `json:"image,omitempty"`
-	Interfaces      []InstanceConfigInterfaceCreateOptions `json:"interfaces,omitempty"`
-	BackupsEnabled  bool                                   `json:"backups_enabled,omitempty"`
-	PrivateIP       bool                                   `json:"private_ip,omitempty"`
-	Tags            []string                               `json:"tags,omitempty"`
-	Metadata        *InstanceMetadataOptions               `json:"metadata,omitempty"`
-	FirewallID      int                                    `json:"firewall_id,omitempty"`
+	Region              string                                 `json:"region"`
+	Type                string                                 `json:"type"`
+	Label               string                                 `json:"label,omitempty"`
+	RootPass            string                                 `json:"root_pass,omitempty"`
+	AuthorizedKeys      []string                               `json:"authorized_keys,omitempty"`
+	AuthorizedUsers     []string                               `json:"authorized_users,omitempty"`
+	StackScriptID       int                                    `json:"stackscript_id,omitempty"`
+	StackScriptData     map[string]string                      `json:"stackscript_data,omitempty"`
+	BackupID            int                                    `json:"backup_id,omitempty"`
+	Image               string                                 `json:"image,omitempty"`
+	Interfaces          []InstanceConfigInterfaceCreateOptions `json:"interfaces,omitempty"`
+	BackupsEnabled      bool                                   `json:"backups_enabled,omitempty"`
+	PrivateIP           bool                                   `json:"private_ip,omitempty"`
+	Tags                []string                               `json:"tags,omitempty"`
+	Metadata            *InstanceMetadataOptions               `json:"metadata,omitempty"`
+	FirewallID          int                                    `json:"firewall_id,omitempty"`
+	InterfaceGeneration InterfaceGeneration                    `json:"interface_generation,omitempty"`
 
 	// NOTE: Disk encryption may not currently be available to all users.
 	DiskEncryption InstanceDiskEncryption `json:"disk_encryption,omitempty"`
@@ -185,6 +211,9 @@ type InstanceCreateOptions struct {
 	Group string `json:"group,omitempty"`
 
 	IPv4 []string `json:"ipv4,omitempty"`
+
+	// NOTE: MaintenancePolicy can only be used with v4beta.
+	MaintenancePolicy *string `json:"maintenance_policy,omitempty"`
 }
 
 // InstanceCreatePlacementGroupOptions represents the placement group
@@ -204,6 +233,9 @@ type InstanceUpdateOptions struct {
 
 	// Deprecated: group is a deprecated property denoting a group label for the Linode.
 	Group *string `json:"group,omitempty"`
+
+	// NOTE: MaintenancePolicy can only be used with v4beta.
+	MaintenancePolicy *string `json:"maintenance_policy,omitempty"`
 }
 
 // UnmarshalJSON implements the json.Unmarshaler interface
@@ -212,6 +244,7 @@ func (i *Instance) UnmarshalJSON(b []byte) error {
 
 	p := struct {
 		*Mask
+
 		Created *parseabletime.ParseableTime `json:"created"`
 		Updated *parseabletime.ParseableTime `json:"updated"`
 	}{
@@ -234,6 +267,7 @@ func (backup *InstanceBackup) UnmarshalJSON(b []byte) error {
 
 	p := struct {
 		*Mask
+
 		LastSuccessful *parseabletime.ParseableTime `json:"last_successful"`
 	}{
 		Mask: (*Mask)(backup),
@@ -251,12 +285,13 @@ func (backup *InstanceBackup) UnmarshalJSON(b []byte) error {
 // GetUpdateOptions converts an Instance to InstanceUpdateOptions for use in UpdateInstance
 func (i *Instance) GetUpdateOptions() InstanceUpdateOptions {
 	return InstanceUpdateOptions{
-		Label:           i.Label,
-		Group:           &i.Group,
-		Backups:         i.Backups,
-		Alerts:          i.Alerts,
-		WatchdogEnabled: &i.WatchdogEnabled,
-		Tags:            &i.Tags,
+		Label:             i.Label,
+		Group:             &i.Group,
+		Backups:           i.Backups,
+		Alerts:            i.Alerts,
+		WatchdogEnabled:   &i.WatchdogEnabled,
+		Tags:              &i.Tags,
+		MaintenancePolicy: &i.MaintenancePolicy,
 	}
 }
 
@@ -299,34 +334,19 @@ type InstanceMigrateOptions struct {
 
 // ListInstances lists linode instances
 func (c *Client) ListInstances(ctx context.Context, opts *ListOptions) ([]Instance, error) {
-	response, err := getPaginatedResults[Instance](ctx, c, "linode/instances", opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return getPaginatedResults[Instance](ctx, c, "linode/instances", opts)
 }
 
 // GetInstance gets the instance with the provided ID
 func (c *Client) GetInstance(ctx context.Context, linodeID int) (*Instance, error) {
 	e := formatAPIPath("linode/instances/%d", linodeID)
-	response, err := doGETRequest[Instance](ctx, c, e)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doGETRequest[Instance](ctx, c, e)
 }
 
 // GetInstanceTransfer gets the instance's network transfer pool statistics for the current month.
 func (c *Client) GetInstanceTransfer(ctx context.Context, linodeID int) (*InstanceTransfer, error) {
 	e := formatAPIPath("linode/instances/%d/transfer", linodeID)
-	response, err := doGETRequest[InstanceTransfer](ctx, c, e)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doGETRequest[InstanceTransfer](ctx, c, e)
 }
 
 // GetInstanceTransferMonthly gets the instance's network transfer pool statistics for a specific month.
@@ -335,26 +355,21 @@ func (c *Client) GetInstanceTransferMonthly(ctx context.Context, linodeID, year,
 	return doGETRequest[MonthlyInstanceTransferStats](ctx, c, e)
 }
 
-// CreateInstance creates a Linode instance
-func (c *Client) CreateInstance(ctx context.Context, opts InstanceCreateOptions) (*Instance, error) {
-	e := "linode/instances"
-	response, err := doPOSTRequest[Instance](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+// GetInstanceTransferMonthlyV2 gets the instance's network transfer pool statistics for a specific month.
+func (c *Client) GetInstanceTransferMonthlyV2(ctx context.Context, linodeID, year, month int) (*MonthlyInstanceTransferStatsV2, error) {
+	e := formatAPIPath("linode/instances/%d/transfer/%d/%d", linodeID, year, month)
+	return doGETRequest[MonthlyInstanceTransferStatsV2](ctx, c, e)
 }
 
-// UpdateInstance creates a Linode instance
+// CreateInstance creates a Linode instance
+func (c *Client) CreateInstance(ctx context.Context, opts InstanceCreateOptions) (*Instance, error) {
+	return doPOSTRequest[Instance](ctx, c, "linode/instances", opts)
+}
+
+// UpdateInstance updates a Linode instance
 func (c *Client) UpdateInstance(ctx context.Context, linodeID int, opts InstanceUpdateOptions) (*Instance, error) {
 	e := formatAPIPath("linode/instances/%d", linodeID)
-	response, err := doPUTRequest[Instance](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPUTRequest[Instance](ctx, c, e, opts)
 }
 
 // RenameInstance renames an Instance
@@ -365,8 +380,7 @@ func (c *Client) RenameInstance(ctx context.Context, linodeID int, label string)
 // DeleteInstance deletes a Linode instance
 func (c *Client) DeleteInstance(ctx context.Context, linodeID int) error {
 	e := formatAPIPath("linode/instances/%d", linodeID)
-	err := doDELETERequest(ctx, c, e)
-	return err
+	return doDELETERequest(ctx, c, e)
 }
 
 // BootInstance will boot a Linode instance
@@ -379,27 +393,20 @@ func (c *Client) BootInstance(ctx context.Context, linodeID int, configID int) e
 	}
 
 	e := formatAPIPath("linode/instances/%d/boot", linodeID)
-	_, err := doPOSTRequest[Instance](ctx, c, e, opts)
-	return err
+
+	return doPOSTRequestNoResponseBody(ctx, c, e, opts)
 }
 
 // CloneInstance clone an existing Instances Disks and Configuration profiles to another Linode Instance
 func (c *Client) CloneInstance(ctx context.Context, linodeID int, opts InstanceCloneOptions) (*Instance, error) {
 	e := formatAPIPath("linode/instances/%d/clone", linodeID)
-	response, err := doPOSTRequest[Instance](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPOSTRequest[Instance](ctx, c, e, opts)
 }
 
 // ResetInstancePassword resets a Linode instance's root password
 func (c *Client) ResetInstancePassword(ctx context.Context, linodeID int, opts InstancePasswordResetOptions) error {
 	e := formatAPIPath("linode/instances/%d/password", linodeID)
-	_, err := doPOSTRequest[Instance](ctx, c, e, opts)
-
-	return err
+	return doPOSTRequestNoResponseBody(ctx, c, e, opts)
 }
 
 // RebootInstance reboots a Linode instance
@@ -412,8 +419,8 @@ func (c *Client) RebootInstance(ctx context.Context, linodeID int, configID int)
 	}
 
 	e := formatAPIPath("linode/instances/%d/reboot", linodeID)
-	_, err := doPOSTRequest[Instance](ctx, c, e, opts)
-	return err
+
+	return doPOSTRequestNoResponseBody(ctx, c, e, opts)
 }
 
 // InstanceRebuildOptions is a struct representing the options to send to the rebuild linode endpoint
@@ -436,12 +443,7 @@ type InstanceRebuildOptions struct {
 // then deploys a new Image to this Linode with the given attributes.
 func (c *Client) RebuildInstance(ctx context.Context, linodeID int, opts InstanceRebuildOptions) (*Instance, error) {
 	e := formatAPIPath("linode/instances/%d/rebuild", linodeID)
-	response, err := doPOSTRequest[Instance](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPOSTRequest[Instance](ctx, c, e, opts)
 }
 
 // InstanceRescueOptions fields are those accepted by RescueInstance
@@ -455,15 +457,13 @@ type InstanceRescueOptions struct {
 // copying data between disks, and downloading files from a disk via SSH and SFTP.
 func (c *Client) RescueInstance(ctx context.Context, linodeID int, opts InstanceRescueOptions) error {
 	e := formatAPIPath("linode/instances/%d/rescue", linodeID)
-	_, err := doPOSTRequest[Instance](ctx, c, e, opts)
-	return err
+	return doPOSTRequestNoResponseBody(ctx, c, e, opts)
 }
 
 // ResizeInstance resizes an instance to new Linode type
 func (c *Client) ResizeInstance(ctx context.Context, linodeID int, opts InstanceResizeOptions) error {
 	e := formatAPIPath("linode/instances/%d/resize", linodeID)
-	_, err := doPOSTRequest[Instance](ctx, c, e, opts)
-	return err
+	return doPOSTRequestNoResponseBody(ctx, c, e, opts)
 }
 
 // ShutdownInstance - Shutdown an instance
@@ -499,10 +499,6 @@ func (c *Client) MigrateInstance(ctx context.Context, linodeID int, opts Instanc
 // simpleInstanceAction is a helper for Instance actions that take no parameters
 // and return empty responses `{}` unless they return a standard error
 func (c *Client) simpleInstanceAction(ctx context.Context, action string, linodeID int) error {
-	_, err := doPOSTRequest[any, any](
-		ctx,
-		c,
-		formatAPIPath("linode/instances/%d/%s", linodeID, action),
-	)
-	return err
+	e := formatAPIPath("linode/instances/%d/%s", linodeID, action)
+	return doPOSTRequestNoRequestResponseBody(ctx, c, e)
 }
