@@ -3,6 +3,7 @@ package linodego
 import (
 	"context"
 	"encoding/json"
+	"fmt"
 	"time"
 
 	"github.com/linode/linodego/internal/parseabletime"
@@ -31,6 +32,9 @@ type LKECluster struct {
 
 	// NOTE: Tier may not currently be available to all users and can only be used with v4beta.
 	Tier string `json:"tier"`
+
+	// NOTE: APLEnabled is currently in beta and may only function with API version v4beta.
+	APLEnabled bool `json:"apl_enabled"`
 }
 
 // LKEClusterCreateOptions fields are those accepted by CreateLKECluster
@@ -44,6 +48,9 @@ type LKEClusterCreateOptions struct {
 
 	// NOTE: Tier may not currently be available to all users and can only be used with v4beta.
 	Tier string `json:"tier,omitempty"`
+
+	// NOTE: APLEnabled is currently in beta and may only function with API version v4beta.
+	APLEnabled bool `json:"apl_enabled,omitempty"`
 }
 
 // LKEClusterUpdateOptions fields are those accepted by UpdateLKECluster
@@ -74,6 +81,22 @@ type LKEVersion struct {
 	ID string `json:"id"`
 }
 
+// LKETierVersion fields are those returned by GetLKETierVersion
+// NOTE: It may not currently be available to all users and can only be used with v4beta.
+type LKETierVersion struct {
+	ID   string         `json:"id"`
+	Tier LKEVersionTier `json:"tier"`
+}
+
+// LKEVersionTier enums represents different LKE tiers
+type LKEVersionTier string
+
+// LKEVersionTier enums start with LKEVersion
+const (
+	LKEVersionStandard   LKEVersionTier = "standard"
+	LKEVersionEnterprise LKEVersionTier = "enterprise"
+)
+
 // LKEClusterRegenerateOptions fields are those accepted by RegenerateLKECluster
 type LKEClusterRegenerateOptions struct {
 	KubeConfig   bool `json:"kubeconfig"`
@@ -86,6 +109,7 @@ func (i *LKECluster) UnmarshalJSON(b []byte) error {
 
 	p := struct {
 		*Mask
+
 		Created *parseabletime.ParseableTime `json:"created"`
 		Updated *parseabletime.ParseableTime `json:"updated"`
 	}{
@@ -178,53 +202,43 @@ func (c *Client) GetLKEVersion(ctx context.Context, version string) (*LKEVersion
 	return response, nil
 }
 
+// ListLKETierVersions lists all Kubernetes versions available given tier through LKE.
+// NOTE: This endpoint may not currently be available to all users and can only be used with v4beta.
+func (c *Client) ListLKETierVersions(ctx context.Context, tier string, opts *ListOptions) ([]LKETierVersion, error) {
+	return getPaginatedResults[LKETierVersion](ctx, c, formatAPIPath("lke/tiers/%s/versions", tier), opts)
+}
+
+// GetLKETierVersion gets the details of a specific LKE tier version.
+// NOTE: This endpoint may not currently be available to all users and can only be used with v4beta.
+func (c *Client) GetLKETierVersion(ctx context.Context, tier string, versionID string) (*LKETierVersion, error) {
+	return doGETRequest[LKETierVersion](ctx, c, formatAPIPath("lke/tiers/%s/versions/%s", tier, versionID))
+}
+
 // ListLKEClusterAPIEndpoints gets the API Endpoint for the LKE Cluster specified
 func (c *Client) ListLKEClusterAPIEndpoints(ctx context.Context, clusterID int, opts *ListOptions) ([]LKEClusterAPIEndpoint, error) {
-	response, err := getPaginatedResults[LKEClusterAPIEndpoint](ctx, c, formatAPIPath("lke/clusters/%d/api-endpoints", clusterID), opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return getPaginatedResults[LKEClusterAPIEndpoint](ctx, c, formatAPIPath("lke/clusters/%d/api-endpoints", clusterID), opts)
 }
 
 // ListLKEClusters lists LKEClusters
 func (c *Client) ListLKEClusters(ctx context.Context, opts *ListOptions) ([]LKECluster, error) {
-	response, err := getPaginatedResults[LKECluster](ctx, c, "lke/clusters", opts)
-	return response, err
+	return getPaginatedResults[LKECluster](ctx, c, "lke/clusters", opts)
 }
 
 // GetLKECluster gets the lkeCluster with the provided ID
 func (c *Client) GetLKECluster(ctx context.Context, clusterID int) (*LKECluster, error) {
 	e := formatAPIPath("lke/clusters/%d", clusterID)
-	response, err := doGETRequest[LKECluster](ctx, c, e)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doGETRequest[LKECluster](ctx, c, e)
 }
 
 // CreateLKECluster creates a LKECluster
 func (c *Client) CreateLKECluster(ctx context.Context, opts LKEClusterCreateOptions) (*LKECluster, error) {
-	e := "lke/clusters"
-	response, err := doPOSTRequest[LKECluster](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPOSTRequest[LKECluster](ctx, c, "lke/clusters", opts)
 }
 
 // UpdateLKECluster updates the LKECluster with the specified id
 func (c *Client) UpdateLKECluster(ctx context.Context, clusterID int, opts LKEClusterUpdateOptions) (*LKECluster, error) {
 	e := formatAPIPath("lke/clusters/%d", clusterID)
-	response, err := doPUTRequest[LKECluster](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPUTRequest[LKECluster](ctx, c, e, opts)
 }
 
 // DeleteLKECluster deletes the LKECluster with the specified id
@@ -236,12 +250,7 @@ func (c *Client) DeleteLKECluster(ctx context.Context, clusterID int) error {
 // GetLKEClusterKubeconfig gets the Kubeconfig for the LKE Cluster specified
 func (c *Client) GetLKEClusterKubeconfig(ctx context.Context, clusterID int) (*LKEClusterKubeconfig, error) {
 	e := formatAPIPath("lke/clusters/%d/kubeconfig", clusterID)
-	response, err := doGETRequest[LKEClusterKubeconfig](ctx, c, e)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doGETRequest[LKEClusterKubeconfig](ctx, c, e)
 }
 
 // DeleteLKEClusterKubeconfig deletes the Kubeconfig for the LKE Cluster specified
@@ -253,30 +262,19 @@ func (c *Client) DeleteLKEClusterKubeconfig(ctx context.Context, clusterID int)
 // GetLKEClusterDashboard gets information about the dashboard for an LKE cluster
 func (c *Client) GetLKEClusterDashboard(ctx context.Context, clusterID int) (*LKEClusterDashboard, error) {
 	e := formatAPIPath("lke/clusters/%d/dashboard", clusterID)
-	response, err := doGETRequest[LKEClusterDashboard](ctx, c, e)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doGETRequest[LKEClusterDashboard](ctx, c, e)
 }
 
 // RecycleLKEClusterNodes recycles all nodes in all pools of the specified LKE Cluster.
 func (c *Client) RecycleLKEClusterNodes(ctx context.Context, clusterID int) error {
 	e := formatAPIPath("lke/clusters/%d/recycle", clusterID)
-	_, err := doPOSTRequest[LKECluster, any](ctx, c, e)
-	return err
+	return doPOSTRequestNoRequestResponseBody(ctx, c, e)
 }
 
 // RegenerateLKECluster regenerates the Kubeconfig file and/or the service account token for the specified LKE Cluster.
 func (c *Client) RegenerateLKECluster(ctx context.Context, clusterID int, opts LKEClusterRegenerateOptions) (*LKECluster, error) {
 	e := formatAPIPath("lke/clusters/%d/regenerate", clusterID)
-	response, err := doPOSTRequest[LKECluster](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPOSTRequest[LKECluster](ctx, c, e, opts)
 }
 
 // DeleteLKEClusterServiceToken deletes and regenerate the service account token for a Cluster.
@@ -284,3 +282,31 @@ func (c *Client) DeleteLKEClusterServiceToken(ctx context.Context, clusterID int
 	e := formatAPIPath("lke/clusters/%d/servicetoken", clusterID)
 	return doDELETERequest(ctx, c, e)
 }
+
+// GetLKEClusterAPLConsoleURL gets the URL of this cluster's APL installation if this cluster is APL-enabled.
+func (c *Client) GetLKEClusterAPLConsoleURL(ctx context.Context, clusterID int) (string, error) {
+	cluster, err := c.GetLKECluster(ctx, clusterID)
+	if err != nil {
+		return "", err
+	}
+
+	if cluster.APLEnabled {
+		return fmt.Sprintf("https://console.lke%d.akamai-apl.net", cluster.ID), nil
+	}
+
+	return "", nil
+}
+
+// GetLKEClusterAPLHealthCheckURL gets the URL of this cluster's APL health check endpoint if this cluster is APL-enabled.
+func (c *Client) GetLKEClusterAPLHealthCheckURL(ctx context.Context, clusterID int) (string, error) {
+	cluster, err := c.GetLKECluster(ctx, clusterID)
+	if err != nil {
+		return "", err
+	}
+
+	if cluster.APLEnabled {
+		return fmt.Sprintf("https://auth.lke%d.akamai-apl.net/ready", cluster.ID), nil
+	}
+
+	return "", nil
+}
