@@ -14,6 +14,16 @@ const (
 	LKELinodeNotReady LKELinodeStatus = "not_ready"
 )
 
+// LKENodePoolUpdateStrategy constants start with LKENodePool and include
+// LKE Node Pool upgrade strategy values
+type LKENodePoolUpdateStrategy string
+
+// LKENodePoolUpdateStrategy constants describe the available upgrade strategies for LKE Enterprise only
+const (
+	LKENodePoolRollingUpdate LKENodePoolUpdateStrategy = "rolling_update"
+	LKENodePoolOnRecycle     LKENodePoolUpdateStrategy = "on_recycle"
+)
+
 // LKENodePoolDisk represents a Node disk in an LKENodePool object
 type LKENodePoolDisk struct {
 	Size int    `json:"size"`
@@ -67,6 +77,11 @@ type LKENodePool struct {
 
 	// NOTE: Disk encryption may not currently be available to all users.
 	DiskEncryption InstanceDiskEncryption `json:"disk_encryption,omitempty"`
+
+	// K8sVersion and UpdateStrategy are only for LKE Enterprise to support node pool upgrades.
+	// It may not currently be available to all users and is under v4beta.
+	K8sVersion     *string                    `json:"k8s_version,omitempty"`
+	UpdateStrategy *LKENodePoolUpdateStrategy `json:"update_strategy,omitempty"`
 }
 
 // LKENodePoolCreateOptions fields are those accepted by CreateLKENodePool
@@ -79,6 +94,11 @@ type LKENodePoolCreateOptions struct {
 	Taints []LKENodePoolTaint `json:"taints"`
 
 	Autoscaler *LKENodePoolAutoscaler `json:"autoscaler,omitempty"`
+
+	// K8sVersion and UpdateStrategy only works for LKE Enterprise to support node pool upgrades.
+	// It may not currently be available to all users and is under v4beta.
+	K8sVersion     *string                    `json:"k8s_version,omitempty"`
+	UpdateStrategy *LKENodePoolUpdateStrategy `json:"update_strategy,omitempty"`
 }
 
 // LKENodePoolUpdateOptions fields are those accepted by UpdateLKENodePoolUpdate
@@ -89,6 +109,11 @@ type LKENodePoolUpdateOptions struct {
 	Taints *[]LKENodePoolTaint `json:"taints,omitempty"`
 
 	Autoscaler *LKENodePoolAutoscaler `json:"autoscaler,omitempty"`
+
+	// K8sVersion and UpdateStrategy only works for LKE Enterprise to support node pool upgrades.
+	// It may not currently be available to all users and is under v4beta.
+	K8sVersion     *string                    `json:"k8s_version,omitempty"`
+	UpdateStrategy *LKENodePoolUpdateStrategy `json:"update_strategy,omitempty"`
 }
 
 // GetCreateOptions converts a LKENodePool to LKENodePoolCreateOptions for
@@ -100,6 +125,9 @@ func (l LKENodePool) GetCreateOptions() (o LKENodePoolCreateOptions) {
 	o.Labels = l.Labels
 	o.Taints = l.Taints
 	o.Autoscaler = &l.Autoscaler
+	o.K8sVersion = l.K8sVersion
+	o.UpdateStrategy = l.UpdateStrategy
+
 	return
 }
 
@@ -110,61 +138,39 @@ func (l LKENodePool) GetUpdateOptions() (o LKENodePoolUpdateOptions) {
 	o.Labels = &l.Labels
 	o.Taints = &l.Taints
 	o.Autoscaler = &l.Autoscaler
+	o.K8sVersion = l.K8sVersion
+	o.UpdateStrategy = l.UpdateStrategy
+
 	return
 }
 
 // ListLKENodePools lists LKENodePools
 func (c *Client) ListLKENodePools(ctx context.Context, clusterID int, opts *ListOptions) ([]LKENodePool, error) {
-	response, err := getPaginatedResults[LKENodePool](ctx, c, formatAPIPath("lke/clusters/%d/pools", clusterID), opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return getPaginatedResults[LKENodePool](ctx, c, formatAPIPath("lke/clusters/%d/pools", clusterID), opts)
 }
 
 // GetLKENodePool gets the LKENodePool with the provided ID
 func (c *Client) GetLKENodePool(ctx context.Context, clusterID, poolID int) (*LKENodePool, error) {
 	e := formatAPIPath("lke/clusters/%d/pools/%d", clusterID, poolID)
-	response, err := doGETRequest[LKENodePool](ctx, c, e)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doGETRequest[LKENodePool](ctx, c, e)
 }
 
 // CreateLKENodePool creates a LKENodePool
 func (c *Client) CreateLKENodePool(ctx context.Context, clusterID int, opts LKENodePoolCreateOptions) (*LKENodePool, error) {
 	e := formatAPIPath("lke/clusters/%d/pools", clusterID)
-	response, err := doPOSTRequest[LKENodePool](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPOSTRequest[LKENodePool](ctx, c, e, opts)
 }
 
 // RecycleLKENodePool recycles a LKENodePool
 func (c *Client) RecycleLKENodePool(ctx context.Context, clusterID, poolID int) error {
 	e := formatAPIPath("lke/clusters/%d/pools/%d/recycle", clusterID, poolID)
-	_, err := doPOSTRequest[LKENodePool, any](ctx, c, e)
-	if err != nil {
-		return err
-	}
-
-	return nil
+	return doPOSTRequestNoRequestResponseBody(ctx, c, e)
 }
 
 // UpdateLKENodePool updates the LKENodePool with the specified id
 func (c *Client) UpdateLKENodePool(ctx context.Context, clusterID, poolID int, opts LKENodePoolUpdateOptions) (*LKENodePool, error) {
 	e := formatAPIPath("lke/clusters/%d/pools/%d", clusterID, poolID)
-	response, err := doPUTRequest[LKENodePool](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPUTRequest[LKENodePool](ctx, c, e, opts)
 }
 
 // DeleteLKENodePool deletes the LKENodePool with the specified id
@@ -176,23 +182,13 @@ func (c *Client) DeleteLKENodePool(ctx context.Context, clusterID, poolID int) e
 // GetLKENodePoolNode gets the LKENodePoolLinode with the provided ID
 func (c *Client) GetLKENodePoolNode(ctx context.Context, clusterID int, nodeID string) (*LKENodePoolLinode, error) {
 	e := formatAPIPath("lke/clusters/%d/nodes/%s", clusterID, nodeID)
-	response, err := doGETRequest[LKENodePoolLinode](ctx, c, e)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doGETRequest[LKENodePoolLinode](ctx, c, e)
 }
 
 // RecycleLKENodePoolNode recycles a LKENodePoolLinode
 func (c *Client) RecycleLKENodePoolNode(ctx context.Context, clusterID int, nodeID string) error {
 	e := formatAPIPath("lke/clusters/%d/nodes/%s/recycle", clusterID, nodeID)
-	_, err := doPOSTRequest[LKENodePoolLinode, any](ctx, c, e)
-	if err != nil {
-		return err
-	}
-
-	return nil
+	return doPOSTRequestNoRequestResponseBody(ctx, c, e)
 }
 
 // DeleteLKENodePoolNode deletes a given node from a node pool
