@@ -74,71 +74,42 @@ func (i InstanceIP) GetUpdateOptions() (o IPAddressUpdateOptions) {
 
 // ListIPAddresses lists IPAddresses.
 func (c *Client) ListIPAddresses(ctx context.Context, opts *ListOptions) ([]InstanceIP, error) {
-	response, err := getPaginatedResults[InstanceIP](ctx, c, "networking/ips", opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return getPaginatedResults[InstanceIP](ctx, c, "networking/ips", opts)
 }
 
 // GetIPAddress gets the IPAddress with the provided IP.
 func (c *Client) GetIPAddress(ctx context.Context, id string) (*InstanceIP, error) {
 	e := formatAPIPath("networking/ips/%s", id)
-	response, err := doGETRequest[InstanceIP](ctx, c, e)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doGETRequest[InstanceIP](ctx, c, e)
 }
 
 // UpdateIPAddressV2 updates the IP address with the specified address.
 func (c *Client) UpdateIPAddressV2(ctx context.Context, address string, opts IPAddressUpdateOptionsV2) (*InstanceIP, error) {
 	e := formatAPIPath("networking/ips/%s", address)
-	response, err := doPUTRequest[InstanceIP](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPUTRequest[InstanceIP](ctx, c, e, opts)
 }
 
 // UpdateIPAddress updates the IP address with the specified id.
 // Deprecated: Please use UpdateIPAddressV2 for all new implementation.
 func (c *Client) UpdateIPAddress(ctx context.Context, id string, opts IPAddressUpdateOptions) (*InstanceIP, error) {
 	e := formatAPIPath("networking/ips/%s", id)
-	response, err := doPUTRequest[InstanceIP](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-
-	return response, nil
+	return doPUTRequest[InstanceIP](ctx, c, e, opts)
 }
 
 // InstancesAssignIPs assigns multiple IPv4 addresses and/or IPv6 ranges to multiple Linodes in one Region.
 // This allows swapping, shuffling, or otherwise reorganizing IPs to your Linodes.
 func (c *Client) InstancesAssignIPs(ctx context.Context, opts LinodesAssignIPsOptions) error {
-	e := "networking/ips/assign"
-	_, err := doPOSTRequest[InstanceIP](ctx, c, e, opts)
-	return err
+	return doPOSTRequestNoResponseBody(ctx, c, "networking/ips/assign", opts)
 }
 
 // ShareIPAddresses allows IP address reassignment (also referred to as IP failover)
 // from one Linode to another if the primary Linode becomes unresponsive.
 func (c *Client) ShareIPAddresses(ctx context.Context, opts IPAddressesShareOptions) error {
-	e := "networking/ips/share"
-	_, err := doPOSTRequest[InstanceIP](ctx, c, e, opts)
-	return err
+	return doPOSTRequestNoResponseBody(ctx, c, "networking/ips/share", opts)
 }
 
 // AllocateReserveIP allocates a new IPv4 address to the Account, with the option to reserve it
 // and optionally assign it to a Linode.
 func (c *Client) AllocateReserveIP(ctx context.Context, opts AllocateReserveIPOptions) (*InstanceIP, error) {
-	e := "networking/ips"
-	result, err := doPOSTRequest[InstanceIP](ctx, c, e, opts)
-	if err != nil {
-		return nil, err
-	}
-	return result, nil
+	return doPOSTRequest[InstanceIP](ctx, c, "networking/ips", opts)
 }
