@@ -2,6 +2,7 @@ package integration
 
 import (
 	"context"
+	"fmt"
 	"net/url"
 	"reflect"
 	"testing"
@@ -67,7 +68,7 @@ func TestLKECluster_Enterprise_smoke(t *testing.T) {
 	client, lkeCluster, teardown, err := setupLKECluster(t, []clusterModifier{func(createOpts *linodego.LKEClusterCreateOptions) {
 		createOpts.Tier = "enterprise"
 		createOpts.Region = "us-lax"
-		createOpts.K8sVersion = "v1.31.1+lke1"
+		createOpts.K8sVersion = ""
 	}}, "fixtures/TestLKECluster_Enterprise_smoke")
 	defer teardown()
 	i, err := client.GetLKECluster(context.Background(), lkeCluster.ID)
@@ -85,6 +86,7 @@ func TestLKECluster_Enterprise_smoke(t *testing.T) {
 func TestLKECluster_Update(t *testing.T) {
 	client, cluster, teardown, err := setupLKECluster(t, []clusterModifier{func(createOpts *linodego.LKEClusterCreateOptions) {
 		createOpts.Label = "go-lke-test-update"
+		createOpts.K8sVersion = "1.31"
 	}}, "fixtures/TestLKECluster_Update")
 	defer teardown()
 	if err != nil {
@@ -93,7 +95,7 @@ func TestLKECluster_Update(t *testing.T) {
 
 	updatedTags := []string{"test=true"}
 	updatedLabel := cluster.Label + "-updated"
-	updatedK8sVersion := "1.30"
+	updatedK8sVersion := "1.32"
 
 	updatedCluster, err := client.UpdateLKECluster(context.Background(), cluster.ID, linodego.LKEClusterUpdateOptions{
 		Tags:       &updatedTags,
@@ -299,6 +301,76 @@ func TestLKEVersions_List(t *testing.T) {
 	}
 }
 
+func TestLKECluster_APLEnabled_smoke(t *testing.T) {
+	client, lkeCluster, teardown, err := setupLKECluster(t, []clusterModifier{
+		func(createOpts *linodego.LKEClusterCreateOptions) {
+			createOpts.Label = "go-lke-test-apl-enabled"
+		},
+		func(createOpts *linodego.LKEClusterCreateOptions) {
+			createOpts.APLEnabled = true
+		},
+		func(createOpts *linodego.LKEClusterCreateOptions) {
+			// NOTE: g6-dedicated-4 is the minimum APL-compatible Linode type
+			createOpts.NodePools = []linodego.LKENodePoolCreateOptions{{Count: 3, Type: "g6-dedicated-4", Tags: []string{"test"}}}
+		},
+	},
+		"fixtures/TestLKECluster_APLEnabled")
+	defer teardown()
+
+	expectedConsoleURL := fmt.Sprintf("https://console.lke%d.akamai-apl.net", lkeCluster.ID)
+	consoleURL, err := client.GetLKEClusterAPLConsoleURL(context.Background(), lkeCluster.ID)
+	if err != nil {
+		t.Errorf("Error getting LKE APL console URL, expected string, got %v and error %v", consoleURL, err)
+	}
+	if consoleURL != expectedConsoleURL {
+		t.Errorf("Expected an APL console URL %v, but got a different one %v", expectedConsoleURL, consoleURL)
+	}
+
+	expectedHealthCheckURL := fmt.Sprintf("https://auth.lke%d.akamai-apl.net/ready", lkeCluster.ID)
+	healthCheckURL, err := client.GetLKEClusterAPLHealthCheckURL(context.Background(), lkeCluster.ID)
+	if err != nil {
+		t.Errorf("Error getting LKE APL health check URL, expected string, got %v and error %v", healthCheckURL, err)
+	}
+	if healthCheckURL != expectedHealthCheckURL {
+		t.Errorf("Expected an APL health check URL %v, but got a different one %v", expectedHealthCheckURL, healthCheckURL)
+	}
+}
+
+func TestLKETierVersion_ListAndGet(t *testing.T) {
+	client, teardown := createTestClient(t, "fixtures/TestLKETierVersion_ListAndGet")
+	defer teardown()
+
+	testCases := []string{"standard", "enterprise"}
+
+	for _, tier := range testCases {
+		t.Run(fmt.Sprintf("Tier=%s", tier), func(t *testing.T) {
+			versions, err := client.ListLKETierVersions(context.Background(), tier, nil)
+			if err != nil {
+				t.Fatalf("Error listing versions: %v", err)
+			}
+
+			if len(versions) == 0 {
+				t.Fatalf("Expected a list of versions for tier %s, but got none", tier)
+			}
+
+			for _, version := range versions {
+				if string(version.Tier) != tier {
+					t.Errorf("Expected version tier %q, but got %q", tier, version.Tier)
+				}
+			}
+
+			v, err := client.GetLKETierVersion(context.Background(), tier, versions[0].ID)
+			if err != nil {
+				t.Fatalf("Error getting version %s for tier %s: %v", versions[0].ID, tier, err)
+			}
+
+			if v.ID != versions[0].ID {
+				t.Errorf("Expected version ID %q, but got %q", versions[0].ID, v.ID)
+			}
+		})
+	}
+}
+
 type clusterModifier func(*linodego.LKEClusterCreateOptions)
 
 func setupLKECluster(t *testing.T, clusterModifiers []clusterModifier, fixturesYaml string) (*linodego.Client, *linodego.LKECluster, func(), error) {
@@ -308,15 +380,29 @@ func setupLKECluster(t *testing.T, clusterModifiers []clusterModifier, fixturesY
 
 	createOpts := linodego.LKEClusterCreateOptions{
 		Label:      label,
-		Region:     getRegionsWithCaps(t, client, []string{"Kubernetes", "Disk Encryption"})[0],
-		K8sVersion: "1.31",
+		Tier:       "standard", // default, can be overridden
 		Tags:       []string{"testing"},
-		NodePools:  []linodego.LKENodePoolCreateOptions{{Count: 1, Type: "g6-standard-2", Tags: []string{"test"}}},
+		Region:     "", // region will be resolved below
+		K8sVersion: "", // will be resolved if empty
+		NodePools: []linodego.LKENodePoolCreateOptions{{
+			Count: 1,
+			Type:  "g6-standard-2",
+			Tags:  []string{"test"},
+		}},
 	}
 
 	for _, modifier := range clusterModifiers {
 		modifier(&createOpts)
 	}
+
+	if createOpts.Region == "" {
+		createOpts.Region = getRegionsWithCaps(t, client, []string{"Kubernetes", "LA Disk Encryption"})[0]
+	}
+
+	if createOpts.K8sVersion == "" {
+		createOpts.K8sVersion = getK8sVersion(t, client, createOpts.Tier)
+	}
+
 	lkeCluster, err := client.CreateLKECluster(context.Background(), createOpts)
 	if err != nil {
 		t.Errorf("failed to create LKE cluster: %s", err)
@@ -330,3 +416,18 @@ func setupLKECluster(t *testing.T, clusterModifiers []clusterModifier, fixturesY
 	}
 	return client, lkeCluster, teardown, err
 }
+
+func getK8sVersion(t *testing.T, client *linodego.Client, tier string) string {
+	t.Helper()
+
+	versions, err := client.ListLKETierVersions(context.Background(), tier, nil)
+	if err != nil {
+		t.Fatalf("Error listing versions for tier %q: %v", tier, err)
+	}
+
+	if len(versions) == 0 {
+		t.Fatalf("Expected a list of versions for tier %q, but got none", tier)
+	}
+
+	return versions[0].ID
+}
