@@ -126,7 +126,29 @@ func TestDatabase_MySQL_Suite(t *testing.T) {
 	if err := client.WaitForDatabaseStatus(
 		context.Background(), database.ID, linodego.DatabaseEngineTypeMySQL,
 		linodego.DatabaseStatusActive, 2400); err != nil {
-		t.Fatalf("failed to wait for database updating: %s", err)
+		t.Fatalf("failed to wait for database active: %s", err)
+	}
+
+	if err := client.SuspendMySQLDatabase(context.Background(), database.ID); err != nil {
+		t.Fatalf("failed to suspend database: %s", err)
+	}
+
+	// Wait for the DB to enter suspended status
+	if err := client.WaitForDatabaseStatus(
+		context.Background(), database.ID, linodego.DatabaseEngineTypeMySQL,
+		linodego.DatabaseStatusSuspended, 240); err != nil {
+		t.Fatalf("failed to wait for database suspended: %s", err)
+	}
+
+	if err := client.ResumeMySQLDatabase(context.Background(), database.ID); err != nil {
+		t.Fatalf("failed to resume database: %s", err)
+	}
+
+	// Wait for the DB to re-enter active status
+	if err := client.WaitForDatabaseStatus(
+		context.Background(), database.ID, linodego.DatabaseEngineTypeMySQL,
+		linodego.DatabaseStatusActive, 2400); err != nil {
+		t.Fatalf("failed to wait for database active: %s", err)
 	}
 }
 
