@@ -32,15 +32,18 @@ func TestAccountEvents_List(t *testing.T) {
 	assert.Equal(t, linodego.EntityType("ticket"), event.Entity.Type)
 	assert.Equal(t, "/v4/support/tickets/11111", event.Entity.URL)
 	assert.Equal(t, 123, event.ID)
-	assert.Equal(t, "None", event.Message)
+	assert.Equal(t, "Ticket created for user issue.", event.Message)
 	assert.Equal(t, true, event.Read)
 	assert.Equal(t, true, event.Seen)
-	assert.Equal(t, linodego.EventStatus("failed"), event.Status)
+	assert.Equal(t, linodego.EventStatus("completed"), event.Status)
 	assert.Equal(t, "exampleUser", event.Username)
 	assert.Equal(t, "linode/debian9", event.SecondaryEntity.ID)
 	assert.Equal(t, "linode1234", event.SecondaryEntity.Label)
 	assert.Equal(t, linodego.EntityType("linode"), event.SecondaryEntity.Type)
 	assert.Equal(t, "/v4/linode/instances/1234", event.SecondaryEntity.URL)
+	assert.Equal(t, "Tentative", event.MaintenancePolicySet)
+	assert.Equal(t, "Scheduled maintenance", event.Description)
+	assert.Equal(t, "user", event.Source)
 }
 
 func TestAccountEvents_Get(t *testing.T) {
@@ -65,13 +68,16 @@ func TestAccountEvents_Get(t *testing.T) {
 	assert.Equal(t, linodego.EntityType("ticket"), event.Entity.Type)
 	assert.Equal(t, "/v4/support/tickets/11111", event.Entity.URL)
 	assert.Equal(t, 123, event.ID)
-	assert.Equal(t, "None", event.Message)
+	assert.Equal(t, "Ticket created for user issue.", event.Message)
 	assert.Equal(t, true, event.Read)
 	assert.Equal(t, true, event.Seen)
-	assert.Equal(t, linodego.EventStatus("failed"), event.Status)
+	assert.Equal(t, linodego.EventStatus("completed"), event.Status)
 	assert.Equal(t, "exampleUser", event.Username)
 	assert.Equal(t, "linode/debian9", event.SecondaryEntity.ID)
 	assert.Equal(t, "linode1234", event.SecondaryEntity.Label)
 	assert.Equal(t, linodego.EntityType("linode"), event.SecondaryEntity.Type)
 	assert.Equal(t, "/v4/linode/instances/1234", event.SecondaryEntity.URL)
+	assert.Equal(t, "Tentative", event.MaintenancePolicySet)
+	assert.Equal(t, "Scheduled maintenance", event.Description)
+	assert.Equal(t, "user", event.Source)
 }
