@@ -29,7 +29,11 @@ func TestAccountPromoCredits_Add(t *testing.T) {
 
 	assert.Equal(t, "10.00", promoCode.CreditMonthlyCap)
 	assert.Equal(t, "50.00", promoCode.CreditRemaining)
-	assert.Equal(t, "Receive up to $10 off your services every month for 6 months! Unused credits will expire once this promotion period ends.", promoCode.Description)
+	assert.Equal(
+		t,
+		"Receive up to $10 off your services every month for 6 months! Unused credits will expire once this promotion period ends.",
+		promoCode.Description,
+	)
 	assert.Equal(t, "https://linode.com/10_a_month_promotion.svg", promoCode.ImageURL)
 	assert.Equal(t, "all", promoCode.ServiceType)
 	assert.Equal(t, "$10 off your Linode a month!", promoCode.Summary)
